==> react-molecule-rating-1.11.0.tgz: package/lib/index.js <==
import { jsxs as _jsxs } from "react/jsx-runtime";
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import cx from 'classnames';
import { ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import Star from './components/Star';
import StarHover from './components/StarHover';
var SIZES = {
  SMALL: ATOM_ICON_SIZES.small,
  MEDIUM: ATOM_ICON_SIZES.medium,
  LARGE: ATOM_ICON_SIZES.large
};
var BASE_CLASS = "sui-MoleculeRating";
var CLASS_CONTAINER_STARS = BASE_CLASS + "-containerStars";
var CLASS_LABEL = BASE_CLASS + "-label";
var CLASS_LINK = BASE_CLASS + "--withLink";
var CLASS_LABEL_LINK = CLASS_LABEL + "Link";

var MoleculeRating = function MoleculeRating(_ref) {
  var _cx;

  var _ref$isHovered = _ref.isHovered,
      isHovered = _ref$isHovered === void 0 ? false : _ref$isHovered,
      _ref$numStars = _ref.numStars,
      numStars = _ref$numStars === void 0 ? 5 : _ref$numStars,
      value = _ref.value,
      ratingValues = _ref.ratingValues,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? SIZES.SMALL : _ref$size,
      label = _ref.label,
      href = _ref.href,
      target = _ref.target,
      onClick = _ref.onClick,
      _ref$linkFactory = _ref.linkFactory,
      Link = _ref$linkFactory === void 0 ? function (_temp) {
    var _ref2 = _temp === void 0 ? {} : _temp,
        children = _ref2.children,
        rest = _objectWithoutPropertiesLoose(_ref2, ["children"]);

    return /*#__PURE__*/_jsx("a", _extends({}, rest, {
      children: children
    }));
  } : _ref$linkFactory,
      props = _objectWithoutPropertiesLoose(_ref, ["isHovered", "numStars", "value", "ratingValues", "size", "label", "href", "target", "onClick", "linkFactory"]);

  var className = cx(BASE_CLASS, BASE_CLASS + "--" + size, (_cx = {}, _cx[CLASS_LINK] = href, _cx));
  var labelLink = href ? /*#__PURE__*/_jsx(Link, {
    className: CLASS_LABEL_LINK,
    href: href,
    target: target,
    rel: target === '_blank' ? 'noopener' : undefined,
    children: label
  }) : label;
  return /*#__PURE__*/_jsxs("div", {
    className: className,
    children: [/*#__PURE__*/_jsx("div", {
      className: CLASS_CONTAINER_STARS,
      children: !isHovered ? new Array(numStars).fill(0).map(function (_, index) {
        return /*#__PURE__*/_jsx(Star, _extends({
          size: size,
          index: index,
          value: value
        }, props), index);
      }) : /*#__PURE__*/_jsx(StarHover, {
        size: size,
        ratingValues: ratingValues,
        onClick: onClick
      })
    }), /*#__PURE__*/_jsx("p", {
      className: CLASS_LABEL,
      children: labelLink
    })]
  });
};

MoleculeRating.displayName = 'MoleculeRating';
export default MoleculeRating;
export { SIZES as MoleculeRatingSizes };

==> react-molecule-rating-1.14.0.tgz: package/lib/index.js <==
import { jsxs as _jsxs } from "react/jsx-runtime";
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import cx from 'classnames';
import { ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import Star from './components/Star';
import StarHover from './components/StarHover';
var SIZES = {
  SMALL: ATOM_ICON_SIZES.small,
  MEDIUM: ATOM_ICON_SIZES.medium,
  LARGE: ATOM_ICON_SIZES.large
};
var BASE_CLASS = "sui-MoleculeRating";
var CLASS_CONTAINER_STARS = BASE_CLASS + "-containerStars";
var CLASS_LABEL = BASE_CLASS + "-label";
var CLASS_LINK = BASE_CLASS + "--withLink";
var CLASS_LABEL_LINK = CLASS_LABEL + "Link";

var MoleculeRating = function MoleculeRating(_ref) {
  var _cx;

  var iconStar = _ref.iconStar,
      initialRating = _ref.initialRating,
      _ref$isHovered = _ref.isHovered,
      isHovered = _ref$isHovered === void 0 ? false : _ref$isHovered,
      _ref$numStars = _ref.numStars,
      numStars = _ref$numStars === void 0 ? 5 : _ref$numStars,
      value = _ref.value,
      ratingValues = _ref.ratingValues,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? SIZES.SMALL : _ref$size,
      label = _ref.label,
      href = _ref.href,
      target = _ref.target,
      onClick = _ref.onClick,
      _ref$linkFactory = _ref.linkFactory,
      Link = _ref$linkFactory === void 0 ? function (_temp) {
    var _ref2 = _temp === void 0 ? {} : _temp,
        children = _ref2.children,
        rest = _objectWithoutPropertiesLoose(_ref2, ["children"]);

    return /*#__PURE__*/_jsx("a", _extends({}, rest, {
      children: children
    }));
  } : _ref$linkFactory,
      props = _objectWithoutPropertiesLoose(_ref, ["iconStar", "initialRating", "isHovered", "numStars", "value", "ratingValues", "size", "label", "href", "target", "onClick", "linkFactory"]);

  var className = cx(BASE_CLASS, BASE_CLASS + "--" + size, (_cx = {}, _cx[CLASS_LINK] = href, _cx));
  var labelLink = href ? /*#__PURE__*/_jsx(Link, {
    className: CLASS_LABEL_LINK,
    href: href,
    target: target,
    rel: target === '_blank' ? 'noopener' : undefined,
    children: label
  }) : label;
  return /*#__PURE__*/_jsxs("div", {
    className: className,
    children: [/*#__PURE__*/_jsx("div", {
      className: CLASS_CONTAINER_STARS,
      children: !isHovered ? new Array(numStars).fill(0).map(function (_, index) {
        return /*#__PURE__*/_jsx(Star, _extends({
          size: size,
          index: index,
          value: value
        }, props), index);
      }) : /*#__PURE__*/_jsx(StarHover, {
        iconStar: iconStar,
        initialRating: initialRating,
        onClick: onClick,
        ratingValues: ratingValues,
        size: size
      })
    }), label && /*#__PURE__*/_jsx("p", {
      className: CLASS_LABEL,
      children: labelLink
    })]
  });
};

MoleculeRating.displayName = 'MoleculeRating';
export default MoleculeRating;
export { SIZES as MoleculeRatingSizes };
